@@ -14,9 +14,9 @@
 
 #include "../UserAction/expander.h"
 
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 
 // for ParameterDialog
 #include "../krusader.h" // for konfig-access
@@ -44,13 +44,13 @@
 #define EXECUTABLE_ID		0xFFFF
 
 
-AddPlaceholderPopup::AddPlaceholderPopup( TQWidget *parent ) : KPopupMenu( parent ) {
+AddPlaceholderPopup::AddPlaceholderPopup( TQWidget *parent ) : TDEPopupMenu( parent ) {
 
-   _activeSub = new KPopupMenu( this );
-   _otherSub = new KPopupMenu( this );
-   _leftSub = new KPopupMenu( this );
-   _rightSub = new KPopupMenu( this );
-   _independentSub = new KPopupMenu( this );
+   _activeSub = new TDEPopupMenu( this );
+   _otherSub = new TDEPopupMenu( this );
+   _leftSub = new TDEPopupMenu( this );
+   _rightSub = new TDEPopupMenu( this );
+   _independentSub = new TDEPopupMenu( this );
 
    insertItem( i18n( "Active panel" ), _activeSub );
    insertItem( i18n( "Other panel" ), _otherSub );
@@ -345,8 +345,8 @@ ParameterFile::ParameterFile( const exp_parameter& parameter, TQWidget* parent )
    hbox->setSpacing( 6 );
    _lineEdit = new KLineEdit( hbox );
    _button = new TQToolButton( hbox);
-   KIconLoader *iconLoader = new KIconLoader();
-  _button->setPixmap( iconLoader->loadIcon( "fileopen", KIcon::Toolbar, 16 ) );
+   TDEIconLoader *iconLoader = new TDEIconLoader();
+  _button->setPixmap( iconLoader->loadIcon( "document-open", TDEIcon::Toolbar, 16 ) );
    connect( _button, TQT_SIGNAL(clicked()), this, TQT_SLOT(addFile()) );
 }
 
@@ -438,8 +438,8 @@ ParameterGoto::ParameterGoto( const exp_parameter& parameter, TQWidget* parent )
    _lineEdit = new KLineEdit( hbox );
    _lineEdit->setCompletionObject( new KURLCompletion( KURLCompletion::DirCompletion ) );
    _dirButton = new TQToolButton( hbox );
-   KIconLoader *iconLoader = new KIconLoader();
-  _dirButton->setPixmap( iconLoader->loadIcon( "fileopen", KIcon::Toolbar, 16 ) );
+   TDEIconLoader *iconLoader = new TDEIconLoader();
+  _dirButton->setPixmap( iconLoader->loadIcon( "document-open", TDEIcon::Toolbar, 16 ) );
    connect( _dirButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(setDir()) );
    _placeholderButton = new TQToolButton( hbox);
    _placeholderButton->setText( i18n("add") );
