@@ -41,10 +41,10 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <tqregexp.h> 
 #include <tqsplitter.h>
 // KDE includes
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kprocess.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kmimetype.h>
 #include <kurl.h>
 #include <ktrader.h>
@@ -52,11 +52,11 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <kuserprofile.h>
 #include <kiconloader.h>
 #include <kcursor.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <tqtooltip.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <tqimage.h>
 #include <tqtabbar.h>
 #include <kdebug.h>
@@ -95,7 +95,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../Dialogs/popularurls.h"
 #include "krpopupmenu.h"
 
-#ifdef __LIBKONTQ__
+#ifdef __LIBKONQ__
 #include <konq_popupmenu.h>
 #include <konqbookmarkmanager.h>
 #endif
@@ -168,13 +168,13 @@ ListPanel::ListPanel( TQString typeIn, TQWidget *parent, bool &left, const char
 	// a cancel button for the inplace refresh mechanism
 	inlineRefreshCancelButton = new KPushButton(this);
 	inlineRefreshCancelButton->setFixedSize( 22, 20 );
-	inlineRefreshCancelButton->setPixmap(krLoader->loadIcon("cancel", KIcon::Toolbar, 16));
+	inlineRefreshCancelButton->setPixmap(krLoader->loadIcon("cancel", TDEIcon::Toolbar, 16));
 	connect(inlineRefreshCancelButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(inlineRefreshCancel()));
 
 	// a quick button to open the popup panel
 	popupBtn = new TQToolButton( this, "popupbtn" );
 	popupBtn->setFixedSize( 22, 20 );
-	popupBtn->setPixmap(krLoader->loadIcon("1uparrow", KIcon::Toolbar, 16));
+	popupBtn->setPixmap(krLoader->loadIcon("1uparrow", TDEIcon::Toolbar, 16));
 	connect(popupBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(togglePanelPopup()));
 	TQToolTip::add(  popupBtn, i18n( "Open the popup panel" ) );
 	totalsLayout->addWidget(totals);
@@ -194,7 +194,7 @@ ListPanel::ListPanel( TQString typeIn, TQWidget *parent, bool &left, const char
 	bool clearButton = krConfig->readBoolEntry("Clear Location Bar Visible", _ClearLocation);
 	if (clearButton){
 		clearOrigin = new TQToolButton(hbox, "clearorigin");
-		clearOrigin->setPixmap(krLoader->loadIcon("locationbar_erase", KIcon::Toolbar, 16));
+		clearOrigin->setPixmap(krLoader->loadIcon("locationbar_erase", TDEIcon::Toolbar, 16));
 		TQToolTip::add(  clearOrigin, i18n( "Clear the location bar" ) );
 	}
 	
@@ -203,7 +203,7 @@ ListPanel::ListPanel( TQString typeIn, TQWidget *parent, bool &left, const char
    TQPixmap pixMap = origin->button() ->iconSet() ->pixmap( TQIconSet::Small, TQIconSet::Normal );
    origin->button() ->setFixedSize( pixMap.width() + 4, pixMap.height() + 4 );
    TQWhatsThis::add
-      ( origin, i18n( "Use superb KDE file dialog to choose location. " ) );
+      ( origin, i18n( "Use superb TDE file dialog to choose location. " ) );
    origin->setShowLocalProtocol( false );
    origin->lineEdit() ->setURLDropsEnabled( true );
    origin->lineEdit() ->installEventFilter( this );
@@ -413,13 +413,13 @@ void ListPanel::togglePanelPopup() {
 		}
 		
 		popup->show();
-		popupBtn->setPixmap(krLoader->loadIcon("1downarrow", KIcon::Toolbar, 16));
+		popupBtn->setPixmap(krLoader->loadIcon("1downarrow", TDEIcon::Toolbar, 16));
 		TQToolTip::add(  popupBtn, i18n( "Close the popup panel" ) );
 	} else {
 		popupSizes.clear();
 		popupSizes = dynamic_cast<TQSplitter*>(popup->parent())->sizes();
 		popup->hide();
-		popupBtn->setPixmap(krLoader->loadIcon("1uparrow", KIcon::Toolbar, 16));
+		popupBtn->setPixmap(krLoader->loadIcon("1uparrow", TDEIcon::Toolbar, 16));
 		TQToolTip::add(  popupBtn, i18n( "Open the popup panel" ) );
 		
 		TQValueList<int> lst;
@@ -594,8 +594,8 @@ void ListPanel::slotFocusOnMe() {
 
    // take care of the 'otherpanel'
    TQPalette q( otherPanel->status->palette() );
-   q.setColor( TQColorGroup::Foreground, KGlobalSettings::textColor() );
-   q.setColor( TQColorGroup::Background, KGlobalSettings::baseColor() );
+   q.setColor( TQColorGroup::Foreground, TDEGlobalSettings::textColor() );
+   q.setColor( TQColorGroup::Background, TDEGlobalSettings::baseColor() );
 
    otherPanel->status->setPalette( q );
    otherPanel->totals->setPalette( q );
@@ -603,8 +603,8 @@ void ListPanel::slotFocusOnMe() {
 
    // now, take care of this panel
    TQPalette p( status->palette() );
-   p.setColor( TQColorGroup::Foreground, KGlobalSettings::highlightedTextColor() );
-   p.setColor( TQColorGroup::Background, KGlobalSettings::highlightColor() );
+   p.setColor( TQColorGroup::Foreground, TDEGlobalSettings::highlightedTextColor() );
+   p.setColor( TQColorGroup::Background, TDEGlobalSettings::highlightColor() );
    status->setPalette( p );
    totals->setPalette( p );
 
@@ -760,8 +760,8 @@ void ListPanel::gotStats( const TQString &mountPoint, unsigned long kBSize,
 	}
 	
 	TQString stats = i18n( "%1 free out of %2 (%3%) on %4 [ (%5) ]" )
-        .arg( KIO::convertSizeFromKB( kBAvail ) )
-        .arg( KIO::convertSizeFromKB( kBSize ) ).arg( perc )
+        .arg( TDEIO::convertSizeFromKB( kBAvail ) )
+        .arg( TDEIO::convertSizeFromKB( kBSize ) ).arg( perc )
         .arg( mountPoint ).arg( fstype );
 	status->setText( stats );
 }
@@ -838,7 +838,7 @@ void ListPanel::handleDropOnView( TQDropEvent *e, TQWidget *widget ) {
        break;
      }
 
-   KIO::CopyJob::CopyMode mode = KIO::CopyJob::Copy;
+   TDEIO::CopyJob::CopyMode mode = TDEIO::CopyJob::Copy;
 
    // the KURL::List is finished, let's go
    // --> display the COPY/MOVE/LINK menu
@@ -854,13 +854,13 @@ void ListPanel::handleDropOnView( TQDropEvent *e, TQWidget *widget ) {
    int result = popup.exec( tmp );
    switch ( result ) {
          case 1 :
-         mode = KIO::CopyJob::Copy;
+         mode = TDEIO::CopyJob::Copy;
          break;
          case 2 :
-         mode = KIO::CopyJob::Move;
+         mode = TDEIO::CopyJob::Move;
          break;
          case 3 :
-         mode = KIO::CopyJob::Link;
+         mode = TDEIO::CopyJob::Link;
          break;
          case - 1 :         // user pressed outside the menu
          case 4:
@@ -1038,7 +1038,7 @@ void ListPanel::panelInactive() {
 	func->files()->vfs_enableRefresh(false);
 }
 
-void ListPanel::slotJobStarted(KIO::Job* job) {
+void ListPanel::slotJobStarted(TDEIO::Job* job) {
 	// disable the parts of the panel we don't want touched
 	//static_cast<KrDetailedView*>(view)->setEnabled(false);
 	status->setEnabled(false);
@@ -1054,14 +1054,14 @@ void ListPanel::slotJobStarted(KIO::Job* job) {
    syncBrowseButton->setEnabled(false);
 
 	// connect to the job interface to provide in-panel refresh notification
-	connect( job, TQT_SIGNAL( infoMessage( KIO::Job*, const TQString & ) ),
-		TQT_SLOT( inlineRefreshInfoMessage( KIO::Job*, const TQString & ) ) );
-	connect( job, TQT_SIGNAL( percent( KIO::Job*, unsigned long ) ),
-      TQT_SLOT( inlineRefreshPercent( KIO::Job*, unsigned long ) ) );		
-	connect(job,TQT_SIGNAL(result(KIO::Job*)),
-         this,TQT_SLOT(inlineRefreshListResult(KIO::Job*)));
-	connect(job,TQT_SIGNAL(canceled(KIO::Job*)),
-         this,TQT_SLOT(inlineRefreshListResult(KIO::Job*)));
+	connect( job, TQT_SIGNAL( infoMessage( TDEIO::Job*, const TQString & ) ),
+		TQT_SLOT( inlineRefreshInfoMessage( TDEIO::Job*, const TQString & ) ) );
+	connect( job, TQT_SIGNAL( percent( TDEIO::Job*, unsigned long ) ),
+      TQT_SLOT( inlineRefreshPercent( TDEIO::Job*, unsigned long ) ) );		
+	connect(job,TQT_SIGNAL(result(TDEIO::Job*)),
+         this,TQT_SLOT(inlineRefreshListResult(TDEIO::Job*)));
+	connect(job,TQT_SIGNAL(canceled(TDEIO::Job*)),
+         this,TQT_SLOT(inlineRefreshListResult(TDEIO::Job*)));
 			
 	inlineRefreshJob = job;
 	
@@ -1076,16 +1076,16 @@ void ListPanel::inlineRefreshCancel() {
 	}
 }
 
-void ListPanel::inlineRefreshPercent( KIO::Job*, unsigned long perc) {
+void ListPanel::inlineRefreshPercent( TDEIO::Job*, unsigned long perc) {
 	TQString msg = TQString(">> %1: %2 % complete...").arg(i18n("Reading")).arg(perc);
 	totals->setText(msg);
 }
 
-void ListPanel::inlineRefreshInfoMessage( KIO::Job*, const TQString &msg ) {
+void ListPanel::inlineRefreshInfoMessage( TDEIO::Job*, const TQString &msg ) {
 	totals->setText(">> " + i18n("Reading: ") + msg);
 }
 
-void ListPanel::inlineRefreshListResult(KIO::Job*) {
+void ListPanel::inlineRefreshListResult(TDEIO::Job*) {
 	inlineRefreshJob = 0;
 	// reenable everything
 	//static_cast<KrDetailedView*>(view)->setEnabled(true);
